#!/usr/bin/python
# -*- coding: utf-8 -*-

#  StartupToIdle
#
#  Coded by Sven H (c) 2022
#  based on StartupToStandby
#  Support: https://dreambox.de/board/
#
# This plugin is open source but it is NOT free software.
#
# This plugin may only be distributed to and executed on hardware which
# is licensed by Dream Property GmbH.
# In other words:
# It's NOT allowed to distribute any parts of this plugin or its source code in ANY way
# to hardware which is NOT licensed by Dream Property GmbH.
# It's NOT allowed to execute this plugin and its source code or even parts of it in ANY way
# on hardware which is NOT licensed by Dream Property GmbH.
#
# If you want to use or modify the code or parts of it, you have to keep the license.

from Screens.Screen import Screen
from Components.ConfigList import ConfigListScreen
from Screens.Setup import SetupSummary
from Screens.MessageBox import MessageBox
from Components.ActionMap import ActionMap
from Components.Sources.StaticText import StaticText
from Components.config import config, getConfigListEntry
from . import _

version_txt = "1.2"

class StartupToIdleConfiguration(Screen, ConfigListScreen):
	"""Configuration of Startup To Idle"""

	def __init__(self, session):
		Screen.__init__(self, session)
		self.skinName = [ "StartupToIdleConfiguration", "Setup" ]

		self.setup_title = _("StartupToIdle Configuration") + " v" + version_txt
		self.onChangedEntry = []

		self["key_red"] = StaticText(_("Cancel"))
		self["key_green"] = StaticText(_("OK"))

		self["actions"] = ActionMap(["SetupActions", "TimerEditActions"],
			{
				"cancel": self.keyCancel,
				"save": self.keySave,
				"log": self.showLastStartLog,
			}
		)

		self.list = []
		ConfigListScreen.__init__(self, self.list, session = session, on_change = self.changed)

		self.createSetup()
		self.onLayoutFinish.append(self.layoutFinished)

	def layoutFinished(self):
		self.setTitle(self.setup_title)

	def createSetup(self):
		self.list = []
		self.list.append(getConfigListEntry(_("startup to idle mode"), config.plugins.startuptoidle.enabled))
		if config.plugins.startuptoidle.enabled.value == "crashOnIdle":
			self.list.append(getConfigListEntry(_("after manual Restart GUI/Restart going to"), config.plugins.startuptoidle.onManualRestart))
		self.list.append(getConfigListEntry(_("debug options")))
		self.list.append(getConfigListEntry(_("activate debug output to console"), config.plugins.startuptoidle.showdebuginfo))
		self.list.append(getConfigListEntry(_("save startlog file to /tmp"), config.plugins.startuptoidle.savestartlog))
		self["config"].setList(self.list)

	def changed(self):
		cur = self["config"].getCurrent()
		if cur and cur[1] == config.plugins.startuptoidle.enabled:
			self.createSetup()
		for x in self.onChangedEntry:
			x()

	def getCurrentEntry(self):
		return self["config"].getCurrent()[0]

	def getCurrentValue(self):
		return str(self["config"].getCurrent()[1].getText())

	def createSummary(self):
		return SetupSummary
	
	def showLastStartLog(self):
		from plugin import lastStartLog
		self.session.open(MessageBox,lastStartLog,MessageBox.TYPE_INFO,title=_("StartupToIdle - last startup log"))

